==> light-sdk-web-form-0.2.7.tgz: package/form/control.js <==
/**
 * @file 表单控件
 * @module control.js
 * @author r2space@gmail.com
 * @version 1.0.0
 */

'use strict';

import React    from 'react'
import ReactDOM from 'react-dom'
import CONST    from '../constant'
import i        from './localize'


export default class Control extends React.Component {

  constructor(props) {
    super(props);
    this.state = {
      scope: this.props.scope
    };

    // 表单类型发生了变化，调整显示的组件
    this.props.option.emitter.on(CONST.EVENT.CHANGE, (event, data) => {
      if (data.name === 'type') {
        this.setState({scope: data.value});
      }
    });
  }

  componentDidMount() {
    $(ReactDOM.findDOMNode(this))
      .find('button')
      .tooltip()
      .draggable({
        cancel: false,
        revert: 'invalid',
        opacity: 0.7,
        helper: function (event) {
          return $(event.currentTarget).clone().css('width', '150');
        }
      });
  }

  render() {
    return React.createElement('div', {className: 'control'}, this.widget());
  }

  widget() {
    return this.props.control.map(button => {

      let display = 'block';
      if (!_.isUndefined(this.state.scope)) {
        if (!_.contains(button.scope, this.state.scope)) {
          display = 'none';
        }
      }

      return React.createElement('button', {
        key: button.name,
        className: button.color + ' control-btn',
        name: button.name,
        title: i(button.description),
        type: 'button',
        style: {display: display},
        'data-title': i(button.title),
        'data-toggle': 'tooltip',
        'data-placement': 'right'
      }, React.createElement('i', {className: 'fa fa-fw fa-' + button.icon}));
    });
  }
}

Control.defaultProps = {
  option: {},
  control: [],
  scope: undefined
};


Control.init = (node, option) => {
  return ReactDOM.render(
    React.createElement(Control, option),
    document.getElementById(node)
  );
};

==> light-sdk-web-form-0.2.9.tgz: package/form/control.js <==
/**
 * @file 表单控件
 * @module control.js
 * @author r2space@gmail.com
 * @version 1.0.0
 */

'use strict';

import React    from 'react'
import ReactDOM from 'react-dom'
import CONST    from '../constant'
import i        from './localize'


export default class Control extends React.Component {

  constructor(props) {
    super(props);
    this.state = {
      scope: this.props.scope
    };

    // 表单类型发生了变化，调整显示的组件
    this.props.option.emitter.on(CONST.EVENT.CHANGE, (event, data) => {
      if (data.name === 'type') {
        this.setState({scope: data.value});
      }
    });
  }

  componentDidMount() {
    $(ReactDOM.findDOMNode(this))
      .find('button')
      .tooltip()
      .draggable({
        cancel: false,
        revert: 'invalid',
        opacity: 0.7,
        helper: function (event) {
          return $(event.currentTarget).clone().css('width', '150');
        }
      });
  }

  render() {
    return React.createElement('div', {className: 'control'}, this.widget());
  }

  widget() {
    return this.props.control.map(button => {

      let display = 'block';
      if (!_.isUndefined(this.state.scope)) {
        if (!button.scope.includes(this.state.scope)) {
          display = 'none';
        }
      }

      return React.createElement('button', {
        key: button.name,
        className: button.color + ' control-btn',
        name: button.name,
        title: i(button.description),
        type: 'button',
        style: {display: display},
        'data-title': i(button.title),
        'data-toggle': 'tooltip',
        'data-placement': 'right'
      }, React.createElement('i', {className: 'fa fa-fw fa-' + button.icon}));
    });
  }
}

Control.defaultProps = {
  option: {},
  control: [],
  scope: undefined
};


Control.init = (node, option) => {
  return ReactDOM.render(
    React.createElement(Control, option),
    document.getElementById(node)
  );
};
